* Supplementary packages employed by Stata
adopath ++ "$Longevity/scripts/libraries/stata"

tempfile t vsl_70
local FEM_data "$Longevity/data/FEM/no_inflation_or_mort_decline"
local FEM_input  "$Longevity/processed/fem"
local FEM_output "$Longevity/results/intermediate/base_1.25"

local texsave_settings "replace autonumber nofix"



*******
* Spending shocks
*******

use "`FEM_output'/c_vsl_w_health_shock_processed.dta", clear
keep  age c_oopmd VSL_oopmd VSL_alt
order age c_oopmd VSL_oopmd VSL_alt

replace c_oopmd = c_oopmd/1000
replace VSL_oopmd = VSL_oopmd/1000
replace VSL_alt = VSL_alt/1000

label var c_oopmd "Non-medical consumption"
label var VSL_oopmd "VSL"
label var VSL_alt "VSL (additional wealth shock)"
label var age "Age"

format c_oopmd %12.0fc
format VSL_oopmd %12.0fc

keep if age<=75
graph twoway line VSL_oopmd age, ytitle("Thousands of dollars", size(vlarge)) xtitle("Age", size(vlarge)) xlabel(,labsize(medlarge)) ylabel(,labsize(medlarge)) lwidth(thick) lcolor(blue) graphregion(color(white)) ylabel(1000(2000)7000,labsize(medlarge))
graph export "$Longevity/results/figures/slide_c_vsl_shock2.pdf", replace as(pdf)





***
* Spaghetti plot of VSL, by age
***
use "`FEM_output'/simulations_processed.dta", clear


replace VSL = VSL/1000



local pct_stats
local graph_nms
local lwidth
local lcolor
local cmd 
foreach x of numlist 1 2 3 4 5(5)95 96 97 98 99 {
	local pct_stats "`pct_stats' (p`x') p`x'_VSL=VSL"
	
	local graph_nms "`graph_nms' p`x'_VSL"
	local lwidth "`lwidth' medium"
	local lcolor "`lcolor' blue*0.2"	
	local cmd "`cmd' || line p`x'_VSL age, lwidth(medium) lcolor(blue*0.2)"
}

collapse (mean) mean_VSL=VSL `pct_stats', by(age) fast

* "By age 70, the VSL inter-vigintile range spans \$1.9 to \$2.9 million."
assert abs(p5_VSL - 1918.0107)<1 if age==70
assert abs(p95_VSL - 2903.012)<1 if age==70

format mean_VSL %12.0fc
label var mean_VSL "Mean"
label var age "Age"
graph twoway `cmd' || line mean_VSL age, lwidth(thick) lcolor(blue) ytitle("VSL (thousands of dollars)", size(medlarge)) graphregion(color(white)) xlabel(,labsize(medlarge)) ylabel(0(2000)7000,labsize(medlarge)) xtitle("Age", size(vlarge)) ytitle("Thousands of dollars", size(vlarge)) legend(off) 
graph export "$Longevity/results/figures/slide_mc_vsl_variance.pdf", replace as(pdf)


** EOF




